import sure  # noqa # pylint: disable=unused-import

from moto import mock_ec2


@mock_ec2
def test_vm_export():
    pass
